#!/bin/bash
# $Id: app.sh 314274 2004-05-24 21:04:46Z geiseri $
# nssi - Copyright (C) 2005,2006 Chris Hammond <chris@bluecobras.com>

# This is a script to automate the install of the ESI NOC Mailscanner Server.
# All that is required is a base install of CentOS 4.2, the script will disable
# the numerous extra services that are not needed, update the yum repository
# files and run a yum update.  It then installs postfix, spamassassin, clamav,
# mailscanner, mailwatch, ntp, http and mysql.  

# v.01 - this is the first functioning version.

# These are per site settings that must be set prior to running this script
FQHN=						#Fully Qualified Host Name, ie. pscm.tac.esi.net
HN=						#Host name of server.
DN=						#Domain Name, ie. tac.esi.net
SUBNET=						#Customer Subnet, ie.
MAILSRV_IP=					#IP Address of the destination mail server
GATEWAY_IP=					#IP Address of the MailScanner server
NET_MASK=					#Subnet Mask
MX_IP=						#MX IP Address
NET_ADDR=					#Network Address
BRD_ADDR=					#Broadcast Address
DEF_ROUTE_IP=					#Default Route
DNS_SRV_1=					#DNS Server 1
DNS_SRV_2=					#DNS Server 2
MAILWTCH_PW=					#Mailwatch db user password
MYSQLROOT_PW=					#Root password for MySQL
ADMMAIL_ACCT=					#Account to receive administrative mail
ROCOMM=						#Read-Only snmp community string
RWCOMM= 					#Read-Write snmp community string
SYSCONTACT=					#SNMP system contact
SHORTORGNAME=					#Short Organization Name
LONGORGNAME=					#Long Organization Name (in "")
ORGWEBSITE=					#Organization Web Site
RAZOR_USER=					#Username for Razor2 Network Registration
RAZOR_PASS=					#Password for Razor2 Network Registration
LOCAL_REPO=					#URL to local yum repository if you have one

# These settings should not be touched.
BASEREPO=/etc/yum.repos.d/CentOS-Base.repo
LOCALREPO=/etc/yum.repos.d/CentOS-Local.repo       
POSTFIX_DIR=/etc/postfix
WEBDIR=/var/www/html
MAILWTCH_DIR=/var/www/html/mailscanner


# Turn off un-needed services that are started by default in CentOS.
while [ "$ans" = "" ]; do
    echo -n "Do you want to turn off unneeded CentOS 4 services? (y/n)"
    read ans
    if [ "$ans" = "" ]; then
	echo ""
	echo ""
	echo "Please enter y or n."
	echo ""
	echo ""
    elif [ "$ans" = "y" ]; then
	chkconfig --level 3 acpid off
        chkconfig --level 3 apmd off
        chkconfig --level 3 autofs off
        chkconfig --level 3 cups off
        chkconfig --level 3 gpm off
        chkconfig --level 3 irqbalance off
        chkconfig --level 3 isdn off
        chkconfig --level 3 kudzu off
        chkconfig --level 3 mdmonitor off
        chkconfig --level 3 netfs off
        chkconfig --level 3 nfslock off
        chkconfig --level 3 pcmcia off
        chkconfig --level 3 portmap off
        chkconfig --level 3 rawdevices off
        chkconfig --level 3 rpcgssd off
        chkconfig --level 3 rpcidmapd off
        chkconfig --level 3 rpcsvcgssd off
        chkconfig --level 3 sendmail off
	echo ""
	echo ""
        echo "Unneeded services have been turned off."
    else
	echo ""
	echo ""
        echo "No services were stopped."
    fi
done

# Import the RPM GPG Keys for yum from the CentOS and Dag repos.
echo ""
echo ""
echo "Importing RPM GPG keys for CentOS and Dag repositories."
echo ""
echo ""
rpm --import http://dag.wieers.com/packages/RPM-GPG-KEY.dag.txt
rpm --import http://mirrors.kernel.org/centos/RPM-GPG-KEY-CentOS-4
echo "RPM GPG keys have been imported."

# Setup the yum repository configuration.
while [ "$ans1" = "" ]; do
    echo ""
    echo ""
    echo "Setting up yum repository configuration."
    echo ""
    echo ""
    echo -n "Will this server us internet accessable repository?  Answering no will use the NOC repository. (y/n)"
    read ans1
    if [ "$ans1" = "" ]; then
	echo ""
        echo ""
	echo "Please enter y or n."
    elif [ "$ans1" = "y" ]; then
	echo "" >> "$BASEREPO"
	echo "[dag]" >> "$BASEREPO"
	echo "name=Dag RPM Repository for Red Hat Enterprise Linux" >> "$BASEREPO"
	echo "baseurl=http://apt.sw.be/redhat/el\$releasever/en/\$basearch/dag" >> "$BASEREPO"
	echo "gpgcheck=1" >> "$BASEREPO"
	echo "enabled=1" >> "$BASEREPO"
    else
        touch "$LOCALREPO"
	echo "#packages used/produced in the build but not released" >> "$LOCALREPO"
	echo "[addons]" >> "$LOCALREPO"
	echo "name=CentOS-$releasever - Addons" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.addons/" >> "$LOCALREPO"
	echo "gpgcheck=1" >> "$LOCALREPO"
	echo "enabled=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "#additional packages that extend functionality of existing packages" >> "$LOCALREPO"
	echo "#[centosplus]" >> "$LOCALREPO"
	echo "#name=CentOS-$releasever - Plus" >> "$LOCALREPO"
	echo "#baseurl="$LOCAL_REPO"/RPMS.centosplus" >> "$LOCALREPO"
	echo "#gpgcheck=1" >> "$LOCALREPO"
	echo "#enabled=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "#contribs - packages by Centos Users" >> "$LOCALREPO"
	echo "[contribs]" >> "$LOCALREPO"
	echo "#packages used/produced in the build but not released" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.contrib" >> "$LOCALREPO"
	echo "gpgcheck=1" >> "$LOCALREPO"
	echo "enabled=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "[dag]" >> "$LOCALREPO"
	echo "name=Dag RPM Repository for Red Hat Enterprise Linux" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.dag" >> "$LOCALREPO"
	echo "gpgcheck=1" >> "$LOCALREPO"
	echo "enabled=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "#additional packages that may be useful" >> "$LOCALREPO"
	echo "[extras]" >> "$LOCALREPO"
	echo "name=CentOS-$releasever - Extras" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.extras" >> "$LOCALREPO"
	echo "gpgcheck=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "#packages in testing" >> "$LOCALREPO"
	echo "[noc]" >> "$LOCALREPO"
	echo "name=CentOS-$releasever - Noc" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.noc" >> "$LOCALREPO"
	echo "gpgcheck=0" >> "$LOCALREPO"
	echo "enabled=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "[base]" >> "$LOCALREPO"
	echo "name=CentOS-$releasever - Base" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.os/" >> "$LOCALREPO"
	echo "gpgcheck=1" >> "$LOCALREPO"
	echo "" >> "$LOCALREPO"
	echo "#released updats" >> "$LOCALREPO"
	echo "[update]" >> "$LOCALREPO"
	echo "name=CentOS-$releasever - Updates" >> "$LOCALREPO"
	echo "baseurl="$LOCAL_REPO"/RPMS.updates/" >> "$LOCALREPO"
	echo "gpgcheck=1" >> "$LOCALREPO"
	mv /etc/yum.repos.d/CentOS-Base.repo /etc/yum.repos.d/CentOS-Base.repo.original
	echo ""
	echo ""    
    	echo "Yum repository configuration complete."
    fi
done

echo ""
echo ""
echo "Perform a yum update to get a fully updated installation."
echo ""
echo ""
while [ "$ans2" = "" ]; do
    echo -n "Would you like to run a yum update? (y/n)"
    read ans2
    if [ "$ans2" = "" ]; then
        echo ""
	echo ""
        echo "Please enter y or n."
	echo ""
	echo ""
    elif [ "$ans2" = "y" ]; then
        echo ""
	echo ""
        echo "Standby while running a yum update."
        echo ""
	echo ""
        yum -y update
	echo ""
	echo ""
    else
        echo ""
	echo ""
        echo "A yum update is recommended, please run as soon as possible!"
	echo ""
	echo ""
    	echo "yum update is complete."
	echo ""
	echo ""
    fi
done

#Update hosts file prior to installing Postfix as the postmap command will fail.
echo "Updating hosts file."
mv /etc/hosts /etc/original_hosts
touch /etc/hosts
echo "127.0.0.1		localhost.localdomain	localhost"  >> /etc/hosts
echo ""$GATEWAY_IP"	"$FQHN"	"$HN"" >> /etc/hosts
echo "Hosts file update is complete."
echo ""
echo ""

# Install all needed rpms in one shot.
echo "Installing required applications and dependencies."
yum -y install postfix postfix-pflogsumm spamassassin clamav clamd clamav-db perl-Archive-Zip perl-Compress-Zlib perl-Convert-BinHex perl-Convert-TNEF perl-HTML-Parser perl-HTML-Tagset perl-IO-stringy perl-MIME-tools perl-MailTools perl-Net-CIDR perl-TimeDate tnef unrar mc zlib-devel perl-Digest-SHA1 db4-devel db4-utils perl-DBI mysql apr apr-util perl-DBD-MySQL mysql-server gd httpd httpd-suexec libidn curl php php-pear php-gd php-mysql perl-Digest-HMAC perl-Net-DNS perl-Time-HiRes perl-URI perl-Net-SSLeay perl-Authen-PAM perl-Convert-BER perl-Mon webmin ntp net-snmp compat-libstdc++-33 perl-DBD-SQLite caching-nameserver

# Install the mailscanner rpms and bitdefender also.
echo "Installing MailScanner and Bitdefender."
rpm -ivh /root/mailscanner/mailscanner-4.52.2-1.noarch.rpm /root/mailscanner/MailScanner-perl-MIME-Base64-3.05-5.i386.rpm /root/mailscanner/BitDefender-Console-Antivirus-7.1-3.linux-gcc3x.i386.rpm /root/mailscanner/perl-Storable-2.15-1.rf.i386.rpm /root/mailscanner/perl-Razor-Agent-2.81-2.i386.rpm

# Install latest logwatch with updates for MailScanner.
echo "Installing latest version of logwatch not in repository."
rpm -Uvh /root/mailscanner/logwatch-7.3-1.noarch.rpm

# Setup MailTo in logwatch.conf
echo "Configuring address to which logwatch will send reports."
sed -i s/'MailTo ='.*/'MailTo = '"$ADMMAIL_ACCT"''/ /usr/share/logwatch/default.conf/logwatch.conf

# Change logrotate config to compress rotated logs.
echo "Configuring logrotate to compress logs."
sed -i s/'#compress'/'compress'/ /etc/logrotate.conf

echo ""
echo ""

# Configure ntpd
echo "Configuring NTP daemon."
mv /etc/ntp.conf /etc/ntp.conf_original
touch /etc/ntp.conf
	echo "#restrict default ignore" >> /etc/ntp.conf
	echo "" >> /etc/ntp.conf
	echo "server  0.pool.ntp.org" >> /etc/ntp.conf
	echo "server  1.pool.ntp.org" >> /etc/ntp.conf
	echo "" >> /etc/ntp.conf
	echo "server 127.127.1.0" >> /etc/ntp.conf
	echo "fudge  127.127.1.0 stratum 10" >> /etc/ntp.conf
	echo "" >> /etc/ntp.conf
	echo "restrict 127.0.0.0 mask 255.0.0.0" >> /etc/ntp.conf
# Enable this to limit access.  I use this to allown ntp monitoring
#	echo "restrict x.x.x.x mask x.x.x.x nomodify nopeer" >> /etc/ntp.conf
	echo "" >> /etc/ntp.conf
	echo "driftfile /etc/ntp/drift" >> /etc/ntp.conf
	echo "" >> /etc/ntp.conf
	echo "multicastclient" >> /etc/ntp.conf
	echo "broadcastdelay  0.008" >> /etc/ntp.conf
touch /etc/ntp/drift /etc/ntp/drift.TEMP
chown ntp /etc/ntp/drift /etc/ntp/drift.TEMP
# Configuration of ntpd complete.
echo "Configuring of NTP daemon complete."

echo ""
echo ""

# Configure snmpd
echo "Configuring SNMP daemon."
mv /etc/snmp/snmpd.conf /etc/snmp/snmpd.conf_original
touch /etc/snmp/snmp.conf
	echo "rwcommunity "$RWCOMM" 127.0.0.1" >> /etc/snmp/snmpd.conf
	echo "rocommunity "$ROCOMM" 127.0.0.1" >> /etc/snmp/snmpd.conf
# Enable this to allow snmp monitoring
#	echo "rwcommunity "$RWCOMM" x.x.x.x" >> /etc/snmp/snmpd.conf
#	echo "rocommunity "$ROCOMM" x.x.x.x" >> /etc/snmp/snmpd.conf
	echo "trapcommunity "$ROCOMM"" >> /etc/snmp/snmpd.conf
	echo "syscontact "$SYSCONTACT"" >> /etc/snmp/snmpd.conf
# Configuration of snmpd complete.
echo "Configuring of SNMP daemon complete."

# Configure /etc/fstab to put /var/spool/MailScanner/incoming in tmpfs
echo "none                    /var/spool/MailScanner/incoming tmpfs   defaults        0 0" >> /etc/fstab

# Modified whatis entry in cron.weekly so it will not fail to run.
sed -i s/'makewhatis -w'/'makewhatis -u -w'/ /etc/cron.weekly/00-makewhatis.cron

# Set sshd to only accept protocol V2.
sed -i s/'#Protocol 2,1'/'Protocol 2'/ /etc/ssh/sshd_config

# Setup firewall and allow required ports
system-config-securitylevel-tui -q --enabled -p ssh:tcp -t eth0
system-config-securitylevel-tui -q --enabled -p www:tcp -t eth0
system-config-securitylevel-tui -q --enabled -p 443:tcp -t eth0
system-config-securitylevel-tui -q --enabled -p smtp:tcp -t eth0
system-config-securitylevel-tui -q --enabled -p 10000:tcp -t eth0

# Turn on extended status on apache for monitoring purposes.
sed -i s/'#ExtendedStatus On'/'ExtendedStatus On'/ /etc/httpd/conf/httpd.conf

# Set MySQL to start on boot and then start so mailwatch can be installed.
echo ""
echo ""
echo "Setting MySLQ to start on boot up and starting MySQL."
echo ""
echo ""

chkconfig --level 3 mysqld on
service mysqld start


# Configure Postfix.
# Back up original Postfix configs to create new configs.
echo ""
echo "Backing up original postfix configs."
echo ""
echo ""
if [ -f "$POSTFIX_DIR"/main.cf ]; then mv "$POSTFIX_DIR"/main.cf "$POSTFIX_DIR"/original_main.cf; fi
if [ -f "$POSTFIX_DIR"/transport ]; then mv "$POSTFIX_DIR"/transport "$POSTFIX_DIR"/original_transport; fi
if [ -f "$POSTFIX_DIR"/header_checks ]; then mv "$POSTFIX_DIR"/header_checks "$POSTFIX_DIR"/original_header_checks; fi
if [ -f "$POSTFIX_DIR"/helo_checks ]; then mv "$POSTFIX_DIR"/helo_checks "$POSTFIX_DIR"/original_helo_checks; fi
echo "Original postfix configs backed up."

# Creating new main.cf.
echo ""
echo ""
echo "Creating new main.cf for postfix."
touch "$POSTFIX_DIR"/main.cf
	echo "# LOCAL PATHNAME INFORMATION" >> "$POSTFIX_DIR"/main.cf
	echo "queue_directory = /var/spool/postfix" >> "$POSTFIX_DIR"/main.cf
	echo "command_directory = /usr/sbin" >> "$POSTFIX_DIR"/main.cf
	echo "daemon_directory = /usr/libexec/postfix" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# QUEUE AND PROCESS OWNERSHIP" >> "$POSTFIX_DIR"/main.cf
	echo "mail_owner = postfix" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# INTERNET HOST AND DOMAIN NAMES" >> "$POSTFIX_DIR"/main.cf
	echo "myhostname = "$FQHN"" >> "$POSTFIX_DIR"/main.cf
	echo "mydomain = "$DN"" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# SENDING MAIL" >> "$POSTFIX_DIR"/main.cf
	echo "myorigin = \$myhostname" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# RECEIVING MAIL" >> "$POSTFIX_DIR"/main.cf
	echo "inet_interfaces = \$myhostname, localhost" >> "$POSTFIX_DIR"/main.cf
	echo "mydestination = \$myhostname, localhost.\$mydomain" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# REJECTING MAIL FOR UNKNOWN LOCAL USERS" >> "$POSTFIX_DIR"/main.cf
	echo "#local_recipient_maps =" >> "$POSTFIX_DIR"/main.cf
	echo "unknown_local_recipient_reject_code = 550" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# TRUST AND RELAY CONTROL" >> "$POSTFIX_DIR"/main.cf
	echo "mynetworks_style = subnet" >> "$POSTFIX_DIR"/main.cf
	echo "mynetworks = "$SUBNET", 127.0.0.0/8" >> "$POSTFIX_DIR"/main.cf
	echo "relay_domains = "$DN"" >> "$POSTFIX_DIR"/main.cf
	echo "#relay_recipient_maps = hash:/etc/postfix/auth_recipients" >> "$POSTFIX_DIR"/main.cf
	echo "#show_user_unknown_table = no" >> "$POSTFIX_DIR"/main.cf	
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# TRANSPORT MAP" >> "$POSTFIX_DIR"/main.cf
	echo "transport_maps = hash:/etc/postfix/transport" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# ALIAS DATABASE" >> "$POSTFIX_DIR"/main.cf
	echo "alias_maps = hash:/etc/aliases" >> "$POSTFIX_DIR"/main.cf
	echo "alias_database = hash:/etc/aliases" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# ADDRESS EXTENSIONS" >> "$POSTFIX_DIR"/main.cf
	echo "#recipient_delimiter = +" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# JUNK MAIL CONTROLS" >> "$POSTFIX_DIR"/main.cf
	echo "header_checks = regexp:/etc/postfix/header_checks" >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# SHOW SOFTWARE VERSION OR NOT" >> "$POSTFIX_DIR"/main.cf
	echo "smtpd_banner = \$myhostname ESMTP \$mail_name USE/SPAM in not welcome here." >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# DEBUGGING CONTROL" >> "$POSTFIX_DIR"/main.cf
	echo "debug_peer_level = 2" >> "$POSTFIX_DIR"/main.cf
	echo "#debug_peer_list = 127.0.0.1" >> "$POSTFIX_DIR"/main.cf
	echo "#debug_peer_list = some.domain" >> "$POSTFIX_DIR"/main.cf
	echo "debugger_command =" >> "$POSTFIX_DIR"/main.cf
	echo '	"PATH=/bin:/usr/bin:/usr/local/bin:/usr/X11R6/bin"' >> "$POSTFIX_DIR"/main.cf
        echo '	"xxgdb \$daemon_directory/\$process_name \$process_id & sleep 5"' >> "$POSTFIX_DIR"/main.cf
	echo "" >> "$POSTFIX_DIR"/main.cf
	echo "# INSTALL-TIME CONFIGURATION INFORMATION" >> "$POSTFIX_DIR"/main.cf
	echo "sendmail_path = /usr/sbin/sendmail.postfix" >> "$POSTFIX_DIR"/main.cf
	echo "newaliases_path = /usr/bin/newaliases.postfix" >> "$POSTFIX_DIR"/main.cf
	echo "mailq_path = /usr/bin/mailq.postfix" >> "$POSTFIX_DIR"/main.cf
	echo "setgid_group = postdrop" >> "$POSTFIX_DIR"/main.cf
	echo "html_directory = no" >> "$POSTFIX_DIR"/main.cf
	echo "manpage_directory = /usr/share/man" >> "$POSTFIX_DIR"/main.cf
	echo "sample_directory = /usr/share/doc/postfix-2.1.5/samples" >> "$POSTFIX_DIR"/main.cf
	echo "readme_directory = /usr/share/doc/postfix-2.1.5/README_FILES" >> "$POSTFIX_DIR"/main.cf
        echo "" >> "$POSTFIX_DIR"/main.cf
        echo "in_flow_delay = 0s" >> "$POSTFIX_DIR"/main.cf
        echo "" >> "$POSTFIX_DIR"/main.cf
        echo "smtpd_delay_reject = yes" >> "$POSTFIX_DIR"/main.cf
        echo "smtpd_helo_required = yes" >> "$POSTFIX_DIR"/main.cf
        echo "smtpd_helo_restrictions =" >> "$POSTFIX_DIR"/main.cf
        echo "   permit_mynetworks," >> "$POSTFIX_DIR"/main.cf
        echo "   check_helo_access" >> "$POSTFIX_DIR"/main.cf
        echo "        hash:/etc/postfix/helo_checks," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_non_fqdn_hostname," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_invalid_hostname," >> "$POSTFIX_DIR"/main.cf
        echo "   permit" >> "$POSTFIX_DIR"/main.cf
        echo "smtpd_sender_restrictions =" >> "$POSTFIX_DIR"/main.cf
        echo "   permit_mynetworks," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_non_fqdn_sender," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_unknown_sender_domain," >> "$POSTFIX_DIR"/main.cf
        echo "   permit" >> "$POSTFIX_DIR"/main.cf
        echo "smtpd_recipient_restrictions =" >> "$POSTFIX_DIR"/main.cf
        echo "   reject_unauth_pipelining," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_non_fqdn_recipient," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_unknown_recipient_domain," >> "$POSTFIX_DIR"/main.cf
        echo "   permit_mynetworks," >> "$POSTFIX_DIR"/main.cf
        echo "   reject_unauth_destination," >> "$POSTFIX_DIR"/main.cf
        echo "#   reject_rbl_client sbl-xbl.spamhaus.org," >> "$POSTFIX_DIR"/main.cf
        echo "#   reject_rbl_client dul.dnsbl.sorbs.net," >> "$POSTFIX_DIR"/main.cf
        echo "#   check_sender_access" >> "$POSTFIX_DIR"/main.cf
        echo "#           hash:/etc/postfix/access," >> "$POSTFIX_DIR"/main.cf
        echo "#   check_sender_access" >> "$POSTFIX_DIR"/main.cf
        echo "#           hash:/etc/postfix/dom-bl-base," >> "$POSTFIX_DIR"/main.cf
        echo "#   check_sender_access" >> "$POSTFIX_DIR"/main.cf
        echo "#           hash:/etc/postfix/dom-bl," >> "$POSTFIX_DIR"/main.cf
        echo "   permit" >> "$POSTFIX_DIR"/main.cf
echo ""
echo ""
echo "New postfix main.cf created."

# Create helo_checks
echo ""
echo ""
echo "Creating new helo_checks for postfix."
touch "$POSTFIX_DIR"/helo_checks
echo "# This file has to be compiled with postmap" >> "$POSTFIX_DIR"/helo_checks
echo "" >> "$POSTFIX_DIR"/helo_checks
echo "# Reject anybody that HELO's as being in our own domain(s)" >> "$POSTFIX_DIR"/helo_checks
echo "# (Note that if you followed the order suggested in the main.cf" >> "$POSTFIX_DIR"/helo_checks
echo "# examples, above, that machines in mynetworks will be okay.)" >> "$POSTFIX_DIR"/helo_checks
echo ""$DN"                           REJECT Internal domain being spoofed." >> "$POSTFIX_DIR"/helo_checks
echo "# Somebody HELO'ing with our IP address?" >> "$POSTFIX_DIR"/helo_checks
echo ""$MX_IP"                        REJECT You are not "$MX_IP"" >> "$POSTFIX_DIR"/helo_checks
echo "# Somebody HELO'ing as localhost?  Impossible, we're localhost" >> "$POSTFIX_DIR"/helo_checks
echo "localhost                       REJECT You are not localhost" >> "$POSTFIX_DIR"/helo_checks
echo ""
echo ""
postmap /etc/postfix/helo_checks
echo "New helo_checks created."

# Add bigandslow to master.cf
echo "bigandslow unix -       -       n       -       -       smtp" >> "$POSTFIX_DIR"/master.cf
echo "        -o smtp_connect_timeout=20" >> "$POSTFIX_DIR"/master.cf


read -p "The next step requires that an interface on the machine be set to "$GATEWAY_IP".  If this is not the case, the configuration will be changed and the network service restarted."

#/etc/resolv.conf (Search Domain and DNS servers)
if [ -f /etc/resolv.conf ]; then mv /etc/resolv.conf /etc/original_resolv.conf; fi
	touch /etc/resolv.conf
		echo "domain "$DN"" >> /etc/resolv.conf
		echo "nameserver 127.0.0.1"
		echo "nameserver "$DNS_SRV_1""
		echo "nameserver "$DNS_SRV_2""

#/etc/sysconfig/network (Hostname and Default Gateway)
sed -i s/'HOSTNAME='.*/'HOSTNAME='"$FQHN"''/ /etc/sysconfig/network
sed -i s/'GATEWAY='.*/'GATEWAY='"$DEF_ROUTE_IP"''/ /etc/sysconfig/network

#/etc/sysconfig/network-scripts/ifcfg-eth0 (IP Address and Subnet Mask)
sed -i s/'IPADDR='.*/'IPADDR='"$GATEWAY_IP"''/ /etc/sysconfig/network
sed -i s/'NETMASK='.*/'NETMASK='"$NET_MASK"''/ /etc/sysconfig/network
sed -i s/'BROADCAST='.*/'BROADCAST='"$BRD_ADDR"''/ /etc/sysconfig/network
sed -i s/'NETWORK='.*/'NETWORK='"$NET_ADDR"''/ /etc/sysconfig/network

# Restart network service.
echo "Restarting Network Service"
service network restart

read -p "Network service has been restarted.  Proper installation may continue."

# Creating new transport file.
echo ""
echo ""
echo "Creating new transport for postfix."
if [ -f "$POSTFIX_DIR"/transport ]; then mv "$POSTFIX_DIR"/transport "$POSTFIX_DIR"/original_transport.cf; fi
	touch "$POSTFIX_DIR"/transport
		echo ""$DN"	smtp:["$MAILSRV_IP"]" >> "$POSTFIX_DIR"/transport
	postmap "$POSTFIX_DIR"/transport
echo "New transport file creation complete."

# Updating the aliase db file.
echo ""
echo ""
echo "Updating the aliase db file postfix."
	sed -i s/'#root:'.*/'root:           '/ /etc/aliases
	sed -i s/'root:'.*/'root:           '"$ADMMAIL_ACCT"''/ /etc/aliases
		newaliases /etc/aliases
echo "Aliase db update complete."

# Creating new header_checks file.
echo "Creating header_checks file for Postfix."
if [ -f "$POSTFIX_DIR"/header_checks ]; then mv "$POSTFIX_DIR"/header_checks "$POSTFIX_DIR"/original_header_checks.cf; fi
	touch "$POSTFIX_DIR"/header_checks
		echo "/^Received:/ HOLD" >> "$POSTFIX_DIR"/header_checks
echo "Header_checks file created."

# Creating auth_recipients file.
echo "Creating auth_recipients for Postfix."
if [ -f "$POSTFIX_DIR"/auth_recipients ]; then mv "$POSTFIX_DIR"/auth_recipients "$POSTFIX_DIR"/original_auth_recipients; fi
	touch "$POSTFIX_DIR"/auth_recipients
		echo "Run postmap /etc/postfix/auth_recipients after editing this file."
echo "Auth_recipients file created."

# Postfix Configuration Complete.
echo "Postfix configuration is complete."	

#Preparing to Configure MailScanner.
echo ""
echo "Configuring MailScanner."

#Start by setting the proper rights to /var/spool/postfix directories.
echo "Setting rights on the /var/spool/postfix directories."
if [ ! -d /var/spool/postfix/active ]; then mkdir -p -m700 /var/spool/postfix/active; fi; chown postfix.root /var/spool/postfix/active
if [ ! -d /var/spool/postfix/bounce ]; then mkdir -p -m700 /var/spool/postfix/bounce; fi; chown postfix.root /var/spool/postfix/bounce
if [ ! -d /var/spool/postfix/corrupt ]; then mkdir -p -m700 /var/spool/postfix/corrupt; fi; chown postfix.root /var/spool/postfix/corrupt
if [ ! -d /var/spool/postfix/defer ]; then mkdir -p -m700 /var/spool/postfix/defer; fi; chown postfix.root /var/spool/postfix/defer
if [ ! -d /var/spool/postfix/deferred ]; then mkdir -p -m700 /var/spool/postfix/deferred; fi; chown postfix.root /var/spool/postfix/deferred
if [ ! -d /var/spool/postfix/flush ]; then mkdir -p -m700 /var/spool/postfix/flush; fi; chown postfix.root /var/spool/postfix/flush
if [ ! -d /var/spool/postfix/hold ]; then mkdir -p -m700 /var/spool/postfix/hold; fi; chown postfix.root /var/spool/postfix/hold
if [ ! -d /var/spool/postfix/incoming ]; then mkdir -p -m730 /var/spool/postfix/incoming; fi; chown postfix.postdrop /var/spool/postfix/incoming
if [ ! -d /var/spool/postfix/pid ]; then mkdir -p -m730 /var/spool/postfix/pid; fi; chown postfix.root /var/spool/postfix/pid
if [ ! -d /var/spool/postfix/private ]; then mkdir -p -m700 /var/spool/postfix/private; fi; chown postfix.root /var/spool/postfix/private
if [ ! -d /var/spool/postfix/public ]; then mkdir -p -m710 /var/spool/postfix/public; fi; chown postfix.postdrop /var/spool/postfix/public
if [ ! -d /var/spool/postfix/saved ]; then mkdir -p -m700 /var/spool/postfix/saved; fi; chown postfix.root /var/spool/postfix/saved
if [ ! -d /var/spool/postfix/trace ]; then mkdir -p -m700 /var/spool/postfix/trace; fi; chown postfix.root /var/spool/postfix/trace

# Create and set rights to /var/spool/MailScanner directories.
echo "Creating directories and setting rights on /var/spool/Mailscanner/incoming and quarantine."
if [ ! -d /var/spool/MailScanner/incoming ]; then mkdir -p /var/spool/MailScanner/incoming; fi; chown postfix.apache /var/spool/MailScanner/incoming
if [ ! -d /var/spool/MailScanner/quarantine ]; then mkdir -p /var/spool/MailScanner/quarantine; fi; chown postfix.apache /var/spool/MailScanner/quarantine 

# Now rights to other directories to which access is required.
echo "Setting rights as required on other misc. directories."
chown root.postdrop /usr/sbin/postqueue
chown root.postdrop /usr/sbin/postdrop
chmod 2755 /usr/sbin/postqueue
chmod 2755 /usr/sbin/postdrop
chown postfix.root /var/spool/postfix
chmod 775 /var/spool/postfix
chown -R clamav.clamav /var/clamav

# Configure MailScanner.
echo "Customizing the MailScanner.conf file."
sed -i s/'%org-name% ='.*/'%org-name% = '"$SHORTORGNAME"''/ /etc/MailScanner/MailScanner.conf
sed -i s/'%org-long-name% ='.*/'%org-long-name% = '"$LONGORGNAME"''/ /etc/MailScanner/MailScanner.conf
sed -i s/'%web-site% ='.*/'%web-site% = '"$ORGWEBSITE"''/ /etc/MailScanner/MailScanner.conf
sed -i s/'^Run As User ='/'Run As User = postfix'/ /etc/MailScanner/MailScanner.conf
sed -i s/'^Run As Group ='/'Run As Group = postfix'/ /etc/MailScanner/MailScanner.conf
sed -i s/'^Incoming Queue Dir'.*/'Incoming Queue Dir = \/var\/spool\/postfix\/hold'/ /etc/MailScanner/MailScanner.conf
sed -i s/'^Outgoing Queue Dir'.*/'Outgoing Queue Dir = \/var\/spool\/postfix\/incoming'/ /etc/MailScanner/MailScanner.conf
sed -i s/'MTA ='.*/'MTA = postfix'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Quarantine User ='.*/'Quarantine User = root'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Quarantine Group ='.*/'Quarantine Group = apache'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Quarantine Permissions ='.*/'Quarantine Permissions = 0660'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Virus Scanning ='.*/'Virus Scanning = %rules-dir%\/virus.scanning.rules'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Virus Scanners ='.*/'Virus Scanners = clamav bitdefender'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Monitors for ClamAV Updates ='.*/'Monitors for ClamAV Updates = \/var\/clamav\/*.cvd'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Quarantine Modified Body ='.*/'Quarantine Modified Body = yes'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Quarantine Whole Message ='.*/'Quarantine Whole Message = yes'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Quarantine Whole Messages As Queue Files ='.*/'Quarantine Whole Messages As Queue Files = no'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Always Include SpamAssassin Report ='.*/'Always Include SpamAssassin Report = yes'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Spam List =' .*/'Spam List = ORDB-RBL SBL+XBL SORBS-DNSBL SORBS-MISC SORBS-DUL SORBS-SMTP DSBL'/ /etc/MailScaner/MailScanner.conf
sed -i s/'Is Definitely Not Spam ='.*/'Is Definitely Not Spam = \&SQLWhitelist'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Is Definitely Spam ='.*/'Is Definitely Spam = \&SQLBlacklist'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Spam Checks ='.*/'Spam Checks = %rules-dir%\/spam.scanning.rules'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Use SpamAssassin ='.*/'Use SpamAssassin = yes'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Required SpamAssassin Score ='.*/'Required SpamAssassin Score = 5'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Spam Actions ='.*/'Spam Actions = store'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Non Spam Actions ='.*/'Non Spam Actions = deliver store'/ /etc/MailScanner/MailScanner.conf
sed -i s/'High Scoring Spam Actions ='.*/'High Scoring Spam Actions = store'/ /etc/MailScanner/MailScanner.conf
sed -i s/'Always Looked Up Last ='.*/'Always Looked Up Last = \&MailWatchLogging'/ /etc/MailScanner/MailScanner.conf

#Create required MailScanner rules to allow release of Quarantined email
echo "Creating MailScanner rules to allow messages to be released from quarantine."
touch /etc/MailScanner/rules/spam.scanning.rules
	echo "From:	127.0.0.1	no" >> /etc/MailScanner/rules/spam.scanning.rules
	echo "FromOrTo:	default	yes" >> /etc/MailScanner/rules/spam.scanning.rules
touch /etc/MailScanner/rules/virus.scanning.rules
	echo "From:	127.0.0.1	no" >> /etc/MailScanner/rules/virus.scanning.rules
	echo "FromOrTo:	default	yes" >> /etc/MailScanner/rules/virus.scanning.rules

# Add settings to stop Windows WMF File Exploits from being passed via email.
# printf "deny\t\.wmf\t\tPossible Microsoft WMF File Exploit attack\t\t\t\t\tPossible Microsoft WMF File Exploit attack" >> /etc/MailScanner/filename.rules.conf
# printf "deny\tmetafont\tNo Windows Metafont Files\tNo Windows Metafont Files allowed" >> /etc/MailScanner/filetype.rules.conf

# Put bayes_cleanup script in cron.daily.
cp /root/mailscanner/etc/cron.daily/bayes_cleanup /etc/cron.daily
chown root.root /etc/cron.daily/bayes_cleanup
chmod 755 /etc/cron.daily/bayes_cleanup

# MailScanner configuration complete
echo "MailScanner configuration complete."
	
# Install and Configure MailWatch
echo "Installing and configuring MailWatch for MailScanner."
echo "Making required changes to /etc/php/ini."
sed -i s/'short_open_tag ='.*/'short_open_tag = On'/ /etc/php.ini
sed -i s/'safe_mode ='.*/'safe_mode = Off'/ /etc/php.ini
sed -i s/'register_globals ='.*/'register_globals = Off'/ /etc/php.ini
sed -i s/'magic_quotes_gpc ='.*/'magic_quotes_gpc = On'/ /etc/php.ini
sed -i s/'magic_quotes_runtime ='.*/'magic_quotes_runtime = Off'/ /etc/php.ini
sed -i s/'session.auto_start ='.*/'session.auto_start = 0'/ /etc/php.ini

echo "Uncompressing mailwatch archive to /root/mailscanner/mailwatch."
cd /root/mailscanner
tar -xzf mailwatch-1.0.3.tar.gz
cd /root/mailscanner/mailwatch

sh fix_quarantine_permissions

echo "Creating database for mailwatch, creating mailwatch database user and setting password and rights."
read -p "When prompted for a password, enter the password selected for mailwatch."
mysql < create.sql
mysql -u root -e"GRANT ALL ON mailscanner.* TO mailwatch@localhost IDENTIFIED BY '"$MAILWTCH_PW"';"
mysql mailscanner -u mailwatch -p -e"INSERT INTO users VALUES ('mailwatch',md5('"$MAILWTCH_PW"'),'mailwatch','A','0','0','0','0','');"

echo "Moving apps from the tools directory to /usr/local/bin."
mv tools/* /usr/local/bin
echo "Moving MailWatch.pm and SQLBlackWhiteList.pm to MailScanner CustomFunctions directory."
mv MailWatch.pm /usr/lib/MailScanner/MailScanner/CustomFunctions
sed -i s/'my(\$db_user) ='.*/'my(\$db_user) = '\'mailwatch\'';'/ /usr/lib/MailScanner/MailScanner/CustomFunctions/MailWatch.pm
sed -i s/'my(\$db_pass) ='.*/'my(\$db_pass) = '\'"$MAILWTCH_PW"\'';'/ /usr/lib/MailScanner/MailScanner/CustomFunctions/MailWatch.pm
mv SQLBlackWhiteList.pm /usr/lib/MailScanner/MailScanner/CustomFunctions
sed -i s/'my(\$db_user) ='.*/'my(\$db_user) = '\'mailwatch\'';'/ /usr/lib/MailScanner/MailScanner/CustomFunctions/SQLBlackWhiteList.pm
sed -i s/'my(\$db_pass) ='.*/'my(\$db_pass) = '\'"$MAILWTCH_PW"\'';'/ /usr/lib/MailScanner/MailScanner/CustomFunctions/SQLBlackWhiteList.pm
mv SQLSpamSettings.pm /usr/lib/MailScanner/MailScanner/CustomFunctions
sed -i s/'my(\$db_user) ='.*/'my(\$db_user) = '\'mailwatch\'';'/ /usr/lib/MailScanner/MailScanner/CustomFunctions/SQLSpamSettings.pm
sed -i s/'my(\$db_pass) ='.*/'my(\$db_pass) = '\'"$MAILWTCH_PW"\'';'/ /usr/lib/MailScanner/MailScanner/CustomFunctions/SQLSpamSettings.pm

echo "Creating images and images/cache directories and setting proper rights."
if [ ! -d "$MAILWTCH_DIR" ]; then mv mailscanner "$WEBDIR"; fi
if [ ! -d "$MAILWTCH_DIR"/images/cache ]; then mkdir "$MAILWTCH_DIR"/images/cache; fi
chown root:apache "$MAILWTCH_DIR"/images
chmod ug+rwx "$MAILWTCH_DIR"/images
chown root:apache "$MAILWTCH_DIR"/images/cache
chmod ug+rwx "$MAILWTCH_DIR"/images/cache

echo "Copy conf.php.example to conf.php and customize."
cp "$MAILWTCH_DIR"/conf.php.example "$MAILWTCH_DIR"/conf.php
sed -i s/'define(DB_USER,'.*/'define(DB_USER, '\'mailwatch\'');'/ "$MAILWTCH_DIR"/conf.php
sed -i s/'define(DB_PASS,'.*/'define(DB_PASS, '\'"$MAILWTCH_PW"\'');'/ "$MAILWTCH_DIR"/conf.php
sed -i s/'define(QUARANTINE_USE_FLAG,'.*/'define(QUARANTINE_USE_FLAG, true);'/ "$MAILWTCH_DIR"/conf.php
sed -i s/'define(QUARANTINE_DAYS_TO_KEEP,'.*/'define(QUARANTINE_DAYS_TO_KEEP, 15);'/ "$MAILWTCH_DIR"/conf.php
sed -i s/'define(QUARANTINE_USE_SENDMAIL,'.*/'define(QUARANTINE_USE_SENDMAIL, true);'/ "$MAILWTCH_DIR"/conf.php
sed -i s/'define(MAX_RESULTS,'.*/'define(MAX_RESULTS, 100);'/ "$MAILWTCH_DIR"/conf.php
sed -i s/'define(AUDIT,'.*/'define(AUDIT, true);'/ "$MAILWTCH_DIR"/conf.php

# Replace do_message_ops.php and geoip_update.php with corrected versions.
cp /root/mailscanner/http/mailscanner/*.php /var/www/html/mailscanner
chown root.root /var/www/html/mailscanner/do_message_ops.php
chown root.root /var/www/html/mailscanner/geoip_update.php
chmod 644 /var/www/html/mailscanner/do_message_ops.php
chmod 644 /var/www/html/mailscanner/geoip_update.php

# Replace db_clean.php with corrected version.
cp /root/mailscanner/usr/local/bin/db_clean.php /usr/local/bin
chown root.root /usr/local/bin/*
chmod 755 /usr/local/bin/*

# Put db_cleanup script in cron.daily.
cp /root/mailscanner/etc/cron.daily/db_cleanup /etc/cron.daily
chown root.root /etc/cron.daily/db_cleanup
chmod 755 /etc/cron.daily/db_cleanup

echo "Creating quarantine_maint.php script and adding to cron.daily."
echo "/usr/local/bin/quarantine_maint.php --clean" > /etc/cron.daily/mailwatch_quarantine_maint.sh
chmod +x /etc/cron.daily/mailwatch_quarantine_maint.sh
echo "Creating quarantine_report.php script and adding to cron.daily."
echo "/usr/local/bin/quarantine_report.php" > /etc/cron.daily/mailwatch_quarantine_report.sh
chmod +x /etc/cron.daily/mailwatch_quarantine_report.sh

echo "Misc. configuration changes."
sed -i s/'\$PackageDir ='.*/'\$PackageDir = "\/usr";'/ /usr/lib/MailScanner/clamav-autoupdate
sed -i s/'^#bayes_path'.*/'bayes_path  \/etc\/MailScanner\/bayes\/bayes'/ /etc/MailScanner/spam.assassin.prefs.conf
sed -i s/'bayes_file_mode'.*/'bayes_file_mode 0660'/ /etc/MailScanner/spam.assassin.prefs.conf
# sed -i s/'bayes_auto_learn_threshold_spam'.*/'bayes_auto_learn_threshold_spam 5.0'/ /usr/share/spamassassin/10_misc.cf

if [ ! -d /etc/MailScanner/bayes ]; then mkdir /etc/MailScanner/bayes; fi
cp /root/mailscanner/bayes/bayes* /etc/MailScanner/bayes
chown postfix:apache /etc/MailScanner/bayes/bayes*
chmod g+rws /etc/MailScanner/bayes/bayes*

if [ ! -d "$MAILWTCH_DIR"/temp ]; then mkdir "$MAILWTCH_DIR"/temp; fi
chown apache.apache "$MAILWTCH_DIR"/temp
chmod u+wr "$MAILWTCH_DIR"/temp

sed -i s/'ServerAdmin'.*/'ServerAdmin ems@tac.esi.net'/ /etc/httpd/conf/httpd.conf		##############################
sed -i s/'#ServerName'.*/'ServerName '"$FQHN"''/ /etc/httpd/conf/httpd.conf

# setup rules_du_jour script
cp /root/mailscanner/rules_du_jour /usr/local/sbin
    chmod +x /usr/local/sbin/rules_du_jour

mkdir /etc/rulesdujour
    touch /etc/rulesdujour/config
	echo "TRUSTED_RULESETS="SARE_ADULT SARE_FRAUD SARE_BML SARE_SPOOF SARE_OEM SARE_RANDOM SARE_HEADER0 SARE_HTML0 SARE_SPECIFIC SARE_OBFU0 SARE_GENLSUBJ0 SARE_UNSUB SARE_URI0"" >> /etc/rulesdujour/config
	echo "SA_DIR="/usr/share/spamassassin"" >> /etc/rulesdujour/config
	echo "MAIL_ADDRESS="ems@tac.esi.net"" >> /etc/rulesdujour/config

    echo "05 1 * * * root /usr/local/sbin/rules_du_jour" >> /etc/crontab

/usr/log/sbin/rules_du_jour

# setup Razor2
razor-admin -create
razor-admin -register -user="$RAZOR_USER" -pass="$RAZOR_PASS"
razor-admin -register -user="$RAZOR_USER" -pass="$RAZOR_PASS"

cp /root/mailscanner/http/favicon.ico "$WEBDIR"

mysql -u root -e"DELETE FROM mysql.user WHERE User = '';"
mysql -u root -e"FLUSH PRIVILEGES;"
mysqladmin -u root password "$MYSQLROOT_PW"
mysqladmin -u root -h "$FQHN" password "$MYSQLROOT_PW"

# Do not set postfix to start on boot as MailScanner will start it for you.
echo "Setting services to start on boot up."
chkconfig --level 3 MailScanner on
chkconfig --level 3 clamd on
chkconfig --level 3 httpd on
chkconfig --level 3 yum on
chkconfig --level 3 ntpd on
chkconfig --level 3 snmpd on
chkconfig --level 3 named on

echo "Do not start these services on boot up."
chkconfig --level 3 spamassassin off
chkconfig --level 3 webmin off
service spamassassin stop
service webmin stop

echo "Starting services."
service MailScanner start
service clamd start
service httpd start
service yum start
service ntpd start
service snmpd start
service named start
echo ""
echo ""
echo "Server setup complete."
